"""
HPA_search_genes_by_query

Search for matching genes by gene name, keywords, or cell line names and return Ensembl ID list. ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def HPA_search_genes_by_query(
    search_query: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search for matching genes by gene name, keywords, or cell line names and return Ensembl ID list. ...

    Parameters
    ----------
    search_query : str
        Gene name, alias, keyword, or cell line name to search for, e.g., 'EGFR', 'TP...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "HPA_search_genes_by_query",
            "arguments": {"search_query": search_query},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["HPA_search_genes_by_query"]
